export type HttpMethod = 'GET' | 'POST' | 'PUT' | 'DELETE';

let instance: API | null = null;

class API {
  baseURL?: string = import.meta.env.VITE_BACKEND_URL;

  constructor() {
    if (instance) {
      return instance;
    }
    instance = this;
  }

  async request<T>(url: string, method: HttpMethod, body?: any, headers?: any): Promise<T> {
    const response = await fetch(this.baseURL + url, {
      method,
      headers: {
        'Content-Type': 'application/json',
        ...headers,
      },
      body: JSON.stringify(body),
    });
  
    if (!response.ok) {
      throw new Error(`Request failed with status ${response.status}`);
    }
  
    const data = await response.json();
    return data as T;
  }
  
  async get<T>(url: string, headers?: any): Promise<T> {
    return this.request<T>(url, 'GET', undefined, headers);
  }
  
  async post<T>(url: string, body: any, headers?: any): Promise<T> {
    return this.request<T>(url, 'POST', body, headers);
  }
  
  async put<T>(url: string, body: any, headers?: any): Promise<T> {
    return this.request<T>(url, 'PUT', body, headers);
  }
  
  async del<T>(url: string, headers?: any): Promise<T> {
    return this.request<T>(url, 'DELETE', undefined, headers);
  }
}

export default Object.freeze(new API());
