import { CallbackWithoutResultAndOptionalError, Schema, model } from "mongoose";
import { passwordHash } from "@/utils/token";
import { IUser } from "../../../../types/user";

const userSchema = new Schema<IUser>({
  email: { type: String, required: true, unique: true },
  avatar: { type: String, required: false },
  password: { type: String, required: true },
  roles: [{ type: String, ref: "Role" }],
  createdAt: { type: Date, default: new Date() }
});

userSchema.pre("save", function(next: CallbackWithoutResultAndOptionalError) {
  // creating a SHA512 hash of the password with salt based on the SECRET environment variable
  this.password = passwordHash(this.password);
  next();
});

const User = model<IUser>("User", userSchema);

export default User;

