import { createToken } from "@/utils/token";
import { Request, Response } from "express";
import { CallbackWithoutResultAndOptionalError } from "mongoose";
import { IUser } from "../../../../../types/user";
import User from "@/models/user/user";

const register = async (req: Request, res: Response, next: CallbackWithoutResultAndOptionalError) => {
    try {
        const { email, password, roles } = req.body as IUser;
        const existingUser = await User.findOne({ email });
        if (existingUser) {
            res.status(400).json({ message: "User already exists" });
            return;
        }
        const user = await User.create({ email, password, roles, createdAt: new Date() });
        const token = createToken(user._id, user.password, user.roles);
        res.cookie("token", token, {
            httpOnly: false,
            expires: new Date(Date.now() + 1000 * 60 * 60 * 24 * 30),
        });
        res.status(201).json({ message: "Registered successfully!", user, success: true });
        next();
    } catch (error: any) {
        next(error);
    }
};

export default register;
